@@ -1,3 +1,3 @@
-from .dataverseBase import DataverseBase
+from .base import DataverseBase
 from .dataset import Dataset
 from .file import File
